==> automl-engine-0.0.3.tar.gz: automl-engine-0.0.3/setup.py <==
import io
import os
from setuptools import setup, find_packages

__version__ = '0.0.3'


for file in os.listdir("dist"):
    if __version__ not in file:
        os.remove(os.path.join('dist', file))
        

def read(*filenames, **kwargs):
    encoding = kwargs.get('encoding', 'utf-8')
    sep = kwargs.get('sep', '\n')
    buf = []
    for filename in filenames:
        with io.open(filename, encoding=encoding) as f:
            buf.append(f.read())
    return sep.join(buf)


long_description = read('README.md')


setup(
    name='automl-engine',
    version=__version__,
    url='https://github.com/lugq1990/automl-engine',
    license='MIT License',
    author='guangqiang.lu',
    install_requires=[
        'pandas',
        'scikit-learn',
        'pyyaml',
        'tensorflow >= 2.1.0',
        'keras-tuner',
        'google-cloud-storage',
        'lightgbm',
        'xgboost',
        'flask',
        'flask_restful',
        'tqdm',
        'numpy'
    ],
    author_email='gqianglu@outlook.com',
    description='3 lines of code for automate machine learning for classification and regression.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=['automl'],
    include_package_data=True,
    platforms='any',
    classifiers = [
        'Development Status :: 3 - Alpha',
        
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        ],
)

==> automl-engine-0.0.4.tar.gz: automl-engine-0.0.4/setup.py <==
import io
import os
from setuptools import setup, find_packages

__version__ = '0.0.4'


# for file in os.listdir("dist"):
#     if __version__ not in file:
#         os.remove(os.path.join('dist', file))
        

def read(*filenames, **kwargs):
    encoding = kwargs.get('encoding', 'utf-8')
    sep = kwargs.get('sep', '\n')
    buf = []
    for filename in filenames:
        with io.open(filename, encoding=encoding) as f:
            buf.append(f.read())
    return sep.join(buf)


long_description = read('README.md')


setup(
    name='automl-engine',
    version=__version__,
    url='https://github.com/lugq1990/automl-engine',
    license='MIT License',
    author='guangqiang.lu',
    install_requires=[
        'pandas',
        'scikit-learn',
        'pyyaml',
        'tensorflow >= 2.1.0',
        'keras-tuner',
        'google-cloud-storage',
        'lightgbm',
        'xgboost',
        'flask',
        'flask_restful',
        'tqdm',
        'numpy'
    ],
    author_email='gqianglu@outlook.com',
    description='3 lines of code for automate machine learning for classification and regression.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=['automl'],
    include_package_data=True,
    platforms='any',
    classifiers = [
        'Development Status :: 3 - Alpha',
        
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        ],
)
